@@ -23,8 +23,9 @@ use Net::RDAP::JCard;
 use vars qw($VERSION);
 use constant DEFAULT_CACHE_TTL => 3600;
 use strict;
+use warnings;
 
-$VERSION = 0.28;
+$VERSION = 0.29;
 
 =pod
 
@@ -32,8 +33,7 @@ $VERSION = 0.28;
 
 =head1 NAME
 
-L<Net::RDAP> - an interface to the Registration Data Access Protocol
-(RDAP).
+L<Net::RDAP> - an interface to the Registration Data Access Protocol (RDAP).
 
 =head1 SYNOPSIS
 
@@ -362,7 +362,7 @@ sub fetch {
 
     }
 
-    if ('HEAD' eq $args{'method'}) {
+    if (exists($args{'method'}) && 'HEAD' eq $args{'method'}) {
         return $self->_head($url);
 
     } else {
@@ -504,28 +504,30 @@ sub rdap_from_response {
 sub object_from_response {
     my ($self, $data, $url) = @_;
 
-    #
-    # lookup results
-    #
-    if    ('domain'     eq $data->{'objectClassName'})  { return Net::RDAP::Object::Domain->new($data,     $url) }
-    elsif ('ip network' eq $data->{'objectClassName'})  { return Net::RDAP::Object::IPNetwork->new($data,  $url) }
-    elsif ('autnum'     eq $data->{'objectClassName'})  { return Net::RDAP::Object::Autnum->new($data,     $url) }
-    elsif ('nameserver' eq $data->{'objectClassName'})  { return Net::RDAP::Object::Nameserver->new($data, $url) }
-    elsif ('entity'     eq $data->{'objectClassName'})  { return Net::RDAP::Object::Entity->new($data,     $url) }
+    if (exists($data->{'objectClassName'})) {
+        #
+        # lookup results
+        #
+        if    ('domain'     eq $data->{'objectClassName'})  { return Net::RDAP::Object::Domain->new($data,     $url) }
+        elsif ('ip network' eq $data->{'objectClassName'})  { return Net::RDAP::Object::IPNetwork->new($data,  $url) }
+        elsif ('autnum'     eq $data->{'objectClassName'})  { return Net::RDAP::Object::Autnum->new($data,     $url) }
+        elsif ('nameserver' eq $data->{'objectClassName'})  { return Net::RDAP::Object::Nameserver->new($data, $url) }
+        elsif ('entity'     eq $data->{'objectClassName'})  { return Net::RDAP::Object::Entity->new($data,     $url) }
 
-    #
-    # 'help' is not a real object type, but Net::RDAP::Service uses the
-    # 'class_override' option to fetch() to ensure we return the right object
-    # type here
-    #
-    elsif ('help'       eq $data->{'objectClassName'})  { return Net::RDAP::Help->new($data, $url) }
+        #
+        # 'help' is not a real object type, but Net::RDAP::Service uses the
+        # 'class_override' option to fetch() to ensure we return the right
+        # object type here
+        #
+        elsif ('help'       eq $data->{'objectClassName'})  { return Net::RDAP::Help->new($data, $url) }
+    }
 
     #
     # search results
     #
-    elsif (defined($data->{'domainSearchResults'}))     { return Net::RDAP::SearchResult->new($data, $url) }
-    elsif (defined($data->{'nameserverSearchResults'})) { return Net::RDAP::SearchResult->new($data, $url) }
-    elsif (defined($data->{'entitySearchResults'}))     { return Net::RDAP::SearchResult->new($data, $url) }
+    elsif (exists($data->{'domainSearchResults'}))     { return Net::RDAP::SearchResult->new($data, $url) }
+    elsif (exists($data->{'nameserverSearchResults'})) { return Net::RDAP::SearchResult->new($data, $url) }
+    elsif (exists($data->{'entitySearchResults'}))     { return Net::RDAP::SearchResult->new($data, $url) }
 
     #
     # unprocessable response
@@ -743,6 +745,9 @@ Protocol (EPP) and Registration Data Access Protocol (RDAP) Status Mapping
 =item * L<https://tools.ietf.org/html/rfc8521> -  Registration Data Access
 Protocol (RDAP) Object Tagging
 
+=item * L<https://tools.ietf.org/html/rfc9536> -  Registration Data Access
+Protocol (RDAP) Reverse Search
+
 =item * L<https://tools.ietf.org/html/rfc9537> -  Redacted Fields in the
 Registration Data Access Protocol (RDAP) Response
 
