@@ -1,11 +1,11 @@
 package Net::RDAP::Object::Autnum;
 use base qw(Net::RDAP::Object);
 use strict;
+use warnings;
 
 =head1 NAME
 
-L<Net::RDAP::Object::Autnum> - an RDAP object representing an
-autonymous system.
+L<Net::RDAP::Object::Autnum> - a module representing an autonymous system.
 
 =head1 DESCRIPTION
 
