@@ -1,12 +1,13 @@
 package Net::RDAP::Registry::IANARegistry::Service;
 use URI;
 use strict;
+use warnings;
 
 =pod
 
 =head1 NAME
 
-L<Net::RDAP::Registry::IANARegistry::Service> - a class which represents
+L<Net::RDAP::Registry::IANARegistry::Service> - a module which represents
 an RDAP service in an IANA bootstrap registry.
 
 =head1 DESCRIPTION
