@@ -1,12 +1,13 @@
 package Net::RDAP::Remark;
 use base qw(Net::RDAP::Base);
 use strict;
+use warnings;
 
 =pod
 
 =head1 NAME
 
-L<Net::RDAP::Remark> - an RDAP remark
+L<Net::RDAP::Remark> - a module representing an RDAP remark.
 
 =head1 DESCRIPTION
 
